==> nm-tray_0.5.0.orig.tar.gz: nm-tray-0.5.0/translations/nm-tray_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Informace o spojení</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Všechny informace</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Aktivní připojení</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Bezdrátové sítě k dispozici</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray – heslo k bezdrátové síti</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="57"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Pro připojení k „%1“ je třeba heslo:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="745"/>
        <source>root</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="747"/>
        <source>active connection(s)</source>
        <translation>aktivní spojení</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="749"/>
        <source>connection(s)</source>
        <translation>spojení</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="751"/>
        <source>device(s)</source>
        <translation>zařízení</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="753"/>
        <source>wifi network(s)</source>
        <translation>WiFi sítě</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1044"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>neznámé</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1153"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1155"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Hardwarová (MAC) adresa</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1157"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Ovladač</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1159"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Rychlost</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1163"/>
        <source>Kb/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1165"/>
        <source>Mb/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1167"/>
        <source>Gb/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1169"/>
        <source>Tb/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1172"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>neznámá</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1176"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Zabezpečení</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1180"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1181"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1192"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>IP Adresa</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1194"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1203"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Výchozí trasa</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1209"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Spojení &lt;strong&gt;%1&lt;/strong&gt;(%2) aktivní&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Žádné aktivní spojení&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Spojení ztraceno</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Nadále už nepřipojeno k %1 „%2“.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Spojení navázáno</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Nyní připojeno k %1 „%2“.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Zapnout síť</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Zapnout WiFi</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Zapnout oznamování</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Informace o připojení</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Ladící informace</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>Wifi – vyžádat sken</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Upravit připojení…</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>nm-tray informace</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>o %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; je jednoduchá nadstavba pro &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;, založená na Qt.&lt;br/&gt;&lt;br/&gt;Verze: %1</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Aktivní připojení</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>WiFi sítě</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Známá připojení</translation>
    </message>
</context>
</TS>

==> nm-tray_0.5.1.orig.tar.gz: nm-tray-0.5.1/translations/nm-tray_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Informace o spojení</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Všechny informace</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Aktivní připojení</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Bezdrátové sítě k dispozici</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray – heslo k bezdrátové síti</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="57"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Pro připojení k „%1“ je třeba heslo:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="745"/>
        <source>root</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="747"/>
        <source>active connection(s)</source>
        <translation>aktivní spojení</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="749"/>
        <source>connection(s)</source>
        <translation>spojení</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="751"/>
        <source>device(s)</source>
        <translation>zařízení</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="753"/>
        <source>wifi network(s)</source>
        <translation>WiFi sítě</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1044"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>neznámé</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1153"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1155"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Hardwarová (MAC) adresa</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1157"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Ovladač</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1159"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Rychlost</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1163"/>
        <source>Kb/s</source>
        <translation>Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1165"/>
        <source>Mb/s</source>
        <translation>Mb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1167"/>
        <source>Gb/s</source>
        <translation>Gb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1169"/>
        <source>Tb/s</source>
        <translation>Tb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1172"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>neznámá</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1176"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Zabezpečení</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1180"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1181"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1192"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>IP Adresa</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1194"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1203"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Výchozí trasa</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1209"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Spojení &lt;strong&gt;%1&lt;/strong&gt;(%2) aktivní&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Žádné aktivní spojení&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Spojení ztraceno</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Nadále už nepřipojeno k %1 „%2“.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Spojení navázáno</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Nyní připojeno k %1 „%2“.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Zapnout síť</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Zapnout WiFi</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Zapnout oznamování</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Informace o připojení</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Ladící informace</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>Wifi – vyžádat sken</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Upravit připojení…</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>nm-tray informace</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>o %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; je jednoduchá nadstavba pro &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;, založená na Qt.&lt;br/&gt;&lt;br/&gt;Verze: %1</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Aktivní připojení</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>WiFi sítě</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Známá připojení</translation>
    </message>
</context>
</TS>
